@@ -116,7 +116,6 @@ class Remote:
         if not new_repo or self.repo:
             assert self.repo == new_repo, "Errors, origin: {self.repo}  != repo_from_gh: {repo} "
             return 
-        logger.info(f"repo.set{new_repo}")
         self._repo = new_repo
         self.user = self._repo.user
         self.remote_name =  self.remote_name or new_repo.user
@@ -227,7 +226,7 @@ class Auto:
             remote_name = target_remote, 
             repo_branch = target_branch,
             fork=False,
-            on_local=True if target_url else False,
+            on_local=True if not target_url else False,
         )
         self.fork_remote = Remote(
             git = self.git,
@@ -235,7 +234,7 @@ class Auto:
             repo = RepositoryID(fork_url) if fork_url else None,
             remote_name = fork_remote,
             fork=True,
-            on_local=True if fork_url else False,
+            on_local=True if not fork_url else False,
         )
         logger.info(f"accepted option parameters. \ntarget_remote: {self.target_remote}\nfork_remote: {self.fork_remote}\n")
         
@@ -386,9 +385,13 @@ class Auto:
         """
         if self.content:
             return
+        if self.target_remote.on_local:
+            title = self.git.get_formated_title(self.target_remote.repo_branch, self.target_remote.local_branch)
+            body = self.git.get_formated_logs(self.target_remote.repo_branch, self.target_remote.local_branch)
+        else:
+            title = "This the first title of pull-request "
+            body = self.git.get_formated_body_from_scratch()
 
-        title = self.git.get_formated_title(self.target_remote.repo_branch, self.target_remote.local_branch)
-        body = self.git.get_formated_logs(self.target_remote.repo_branch, self.target_remote.local_branch)
         if not self.skip_editor:
             edited = self.git.editor_str(str(PRContent(title, body)))
             self.content.fill_empty(PRContent(content=edited))
